pub struct Channel(/* private fields */);Expand description
Channel
Implementations
Sourceimpl Channel
impl Channel
Sourcepub unsafe fn new_unchecked(name: String) -> Channel
pub unsafe fn new_unchecked(name: String) -> Channel
Create channel with arbitrary name, bypassing name validity checks
Not recommened! Use new() method above instead.
Safety
Only if Channel::is_valid_name(name)
Sourcepub fn is_valid_name(name: &str) -> bool
pub fn is_valid_name(name: &str) -> bool
Check if given name is a valid channel name
Valid channel name can contain only English letters (A-Z, a-z),
numbers (0-9), underscore, forward slash, dot and colon (_, /, ., :)